==> chaosmesh-model-6.3.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosActionsFluentImpl<A extends PodHttpChaosActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosActionsFluent<A>{
  public PodHttpChaosActionsFluentImpl() {
  }
  public PodHttpChaosActionsFluentImpl(PodHttpChaosActions instance) {
    this.withAbort(instance.getAbort()); 
    this.withDelay(instance.getDelay()); 
    this.withPatch(instance.getPatch()); 
    this.withReplace(instance.getReplace()); 
  }
  private Boolean abort;
  private String delay;
  private PodHttpChaosPatchActionsBuilder patch;
  private PodHttpChaosReplaceActionsBuilder replace;
  public Boolean getAbort() {
    return this.abort;
  }
  public A withAbort(Boolean abort) {
    this.abort=abort; return (A) this;
  }
  public Boolean hasAbort() {
    return this.abort != null;
  }
  public String getDelay() {
    return this.delay;
  }
  public A withDelay(String delay) {
    this.delay=delay; return (A) this;
  }
  public Boolean hasDelay() {
    return this.delay != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchActions getPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public A withPatch(PodHttpChaosPatchActions patch) {
    _visitables.get("patch").remove(this.patch);
    if (patch!=null){ this.patch= new PodHttpChaosPatchActionsBuilder(patch); _visitables.get("patch").add(this.patch);} else { this.patch = null; _visitables.get("patch").remove(this.patch); } return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public PodHttpChaosActionsFluent.PatchNested<A> withNewPatch() {
    return new PodHttpChaosActionsFluentImpl.PatchNestedImpl();
  }
  public PodHttpChaosActionsFluent.PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PodHttpChaosActionsFluentImpl.PatchNestedImpl(item);
  }
  public PodHttpChaosActionsFluent.PatchNested<A> editPatch() {
    return withNewPatchLike(getPatch());
  }
  public PodHttpChaosActionsFluent.PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(getPatch() != null ? getPatch(): new PodHttpChaosPatchActionsBuilder().build());
  }
  public PodHttpChaosActionsFluent.PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(getPatch() != null ? getPatch(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildReplace instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosReplaceActions getReplace() {
    return this.replace!=null ?this.replace.build():null;
  }
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace!=null ?this.replace.build():null;
  }
  public A withReplace(PodHttpChaosReplaceActions replace) {
    _visitables.get("replace").remove(this.replace);
    if (replace!=null){ this.replace= new PodHttpChaosReplaceActionsBuilder(replace); _visitables.get("replace").add(this.replace);} else { this.replace = null; _visitables.get("replace").remove(this.replace); } return (A) this;
  }
  public Boolean hasReplace() {
    return this.replace != null;
  }
  public PodHttpChaosActionsFluent.ReplaceNested<A> withNewReplace() {
    return new PodHttpChaosActionsFluentImpl.ReplaceNestedImpl();
  }
  public PodHttpChaosActionsFluent.ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new PodHttpChaosActionsFluentImpl.ReplaceNestedImpl(item);
  }
  public PodHttpChaosActionsFluent.ReplaceNested<A> editReplace() {
    return withNewReplaceLike(getReplace());
  }
  public PodHttpChaosActionsFluent.ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(getReplace() != null ? getReplace(): new PodHttpChaosReplaceActionsBuilder().build());
  }
  public PodHttpChaosActionsFluent.ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(getReplace() != null ? getReplace(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    PodHttpChaosActionsFluentImpl that = (PodHttpChaosActionsFluentImpl) o;
    if (abort != null ? !abort.equals(that.abort) :that.abort != null) return false;
    if (delay != null ? !delay.equals(that.delay) :that.delay != null) return false;
    if (patch != null ? !patch.equals(that.patch) :that.patch != null) return false;
    if (replace != null ? !replace.equals(that.replace) :that.replace != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  patch,  replace,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace); }
    sb.append("}");
    return sb.toString();
  }
  public A withAbort() {
    return withAbort(true);
  }
  class PatchNestedImpl<N> extends PodHttpChaosPatchActionsFluentImpl<PodHttpChaosActionsFluent.PatchNested<N>> implements PodHttpChaosActionsFluent.PatchNested<N>,Nested<N>{
    PatchNestedImpl(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PatchNestedImpl() {
      this.builder = new PodHttpChaosPatchActionsBuilder(this);
    }
    PodHttpChaosPatchActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosActionsFluentImpl.this.withPatch(builder.build());
    }
    public N endPatch() {
      return and();
    }
    
  }
  class ReplaceNestedImpl<N> extends PodHttpChaosReplaceActionsFluentImpl<PodHttpChaosActionsFluent.ReplaceNested<N>> implements PodHttpChaosActionsFluent.ReplaceNested<N>,Nested<N>{
    ReplaceNestedImpl(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    ReplaceNestedImpl() {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosActionsFluentImpl.this.withReplace(builder.build());
    }
    public N endReplace() {
      return and();
    }
    
  }
  
}

==> chaosmesh-model-6.7.0-sources.jar: io/fabric8/chaosmesh/v1alpha1/PodHttpChaosActionsFluentImpl.java <==
package io.fabric8.chaosmesh.v1alpha1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class PodHttpChaosActionsFluentImpl<A extends PodHttpChaosActionsFluent<A>> extends BaseFluent<A> implements PodHttpChaosActionsFluent<A>{
  public PodHttpChaosActionsFluentImpl() {
  }
  public PodHttpChaosActionsFluentImpl(PodHttpChaosActions instance) {
    if (instance != null) {
      this.withAbort(instance.getAbort());
      this.withDelay(instance.getDelay());
      this.withPatch(instance.getPatch());
      this.withReplace(instance.getReplace());
    }
  }
  private Boolean abort;
  private String delay;
  private PodHttpChaosPatchActionsBuilder patch;
  private PodHttpChaosReplaceActionsBuilder replace;
  public Boolean getAbort() {
    return this.abort;
  }
  public A withAbort(Boolean abort) {
    this.abort=abort; return (A) this;
  }
  public Boolean hasAbort() {
    return this.abort != null;
  }
  public String getDelay() {
    return this.delay;
  }
  public A withDelay(String delay) {
    this.delay=delay; return (A) this;
  }
  public Boolean hasDelay() {
    return this.delay != null;
  }
  
  /**
   * This method has been deprecated, please use method buildPatch instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosPatchActions getPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public PodHttpChaosPatchActions buildPatch() {
    return this.patch!=null ?this.patch.build():null;
  }
  public A withPatch(PodHttpChaosPatchActions patch) {
    _visitables.get("patch").remove(this.patch);
    if (patch!=null){ this.patch= new PodHttpChaosPatchActionsBuilder(patch); _visitables.get("patch").add(this.patch);} else { this.patch = null; _visitables.get("patch").remove(this.patch); } return (A) this;
  }
  public Boolean hasPatch() {
    return this.patch != null;
  }
  public PodHttpChaosActionsFluentImpl.PatchNested<A> withNewPatch() {
    return new PodHttpChaosActionsFluentImpl.PatchNestedImpl();
  }
  public PodHttpChaosActionsFluentImpl.PatchNested<A> withNewPatchLike(PodHttpChaosPatchActions item) {
    return new PodHttpChaosActionsFluentImpl.PatchNestedImpl(item);
  }
  public PodHttpChaosActionsFluentImpl.PatchNested<A> editPatch() {
    return withNewPatchLike(getPatch());
  }
  public PodHttpChaosActionsFluentImpl.PatchNested<A> editOrNewPatch() {
    return withNewPatchLike(getPatch() != null ? getPatch(): new PodHttpChaosPatchActionsBuilder().build());
  }
  public PodHttpChaosActionsFluentImpl.PatchNested<A> editOrNewPatchLike(PodHttpChaosPatchActions item) {
    return withNewPatchLike(getPatch() != null ? getPatch(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildReplace instead.
   * @return The buildable object.
   */
  @Deprecated
  public PodHttpChaosReplaceActions getReplace() {
    return this.replace!=null ?this.replace.build():null;
  }
  public PodHttpChaosReplaceActions buildReplace() {
    return this.replace!=null ?this.replace.build():null;
  }
  public A withReplace(PodHttpChaosReplaceActions replace) {
    _visitables.get("replace").remove(this.replace);
    if (replace!=null){ this.replace= new PodHttpChaosReplaceActionsBuilder(replace); _visitables.get("replace").add(this.replace);} else { this.replace = null; _visitables.get("replace").remove(this.replace); } return (A) this;
  }
  public Boolean hasReplace() {
    return this.replace != null;
  }
  public PodHttpChaosActionsFluentImpl.ReplaceNested<A> withNewReplace() {
    return new PodHttpChaosActionsFluentImpl.ReplaceNestedImpl();
  }
  public PodHttpChaosActionsFluentImpl.ReplaceNested<A> withNewReplaceLike(PodHttpChaosReplaceActions item) {
    return new PodHttpChaosActionsFluentImpl.ReplaceNestedImpl(item);
  }
  public PodHttpChaosActionsFluentImpl.ReplaceNested<A> editReplace() {
    return withNewReplaceLike(getReplace());
  }
  public PodHttpChaosActionsFluentImpl.ReplaceNested<A> editOrNewReplace() {
    return withNewReplaceLike(getReplace() != null ? getReplace(): new PodHttpChaosReplaceActionsBuilder().build());
  }
  public PodHttpChaosActionsFluentImpl.ReplaceNested<A> editOrNewReplaceLike(PodHttpChaosReplaceActions item) {
    return withNewReplaceLike(getReplace() != null ? getReplace(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    PodHttpChaosActionsFluentImpl that = (PodHttpChaosActionsFluentImpl) o;
    if (!java.util.Objects.equals(abort, that.abort)) return false;

    if (!java.util.Objects.equals(delay, that.delay)) return false;

    if (!java.util.Objects.equals(patch, that.patch)) return false;

    if (!java.util.Objects.equals(replace, that.replace)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(abort,  delay,  patch,  replace,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (abort != null) { sb.append("abort:"); sb.append(abort + ","); }
    if (delay != null) { sb.append("delay:"); sb.append(delay + ","); }
    if (patch != null) { sb.append("patch:"); sb.append(patch + ","); }
    if (replace != null) { sb.append("replace:"); sb.append(replace); }
    sb.append("}");
    return sb.toString();
  }
  public A withAbort() {
    return withAbort(true);
  }
  class PatchNestedImpl<N> extends PodHttpChaosPatchActionsFluentImpl<PodHttpChaosActionsFluentImpl.PatchNested<N>> implements PodHttpChaosActionsFluentImpl.PatchNested<N>,Nested<N>{
    PatchNestedImpl(PodHttpChaosPatchActions item) {
      this.builder = new PodHttpChaosPatchActionsBuilder(this, item);
    }
    PatchNestedImpl() {
      this.builder = new PodHttpChaosPatchActionsBuilder(this);
    }
    PodHttpChaosPatchActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosActionsFluentImpl.this.withPatch(builder.build());
    }
    public N endPatch() {
      return and();
    }
    
  }
  class ReplaceNestedImpl<N> extends PodHttpChaosReplaceActionsFluentImpl<PodHttpChaosActionsFluentImpl.ReplaceNested<N>> implements PodHttpChaosActionsFluentImpl.ReplaceNested<N>,Nested<N>{
    ReplaceNestedImpl(PodHttpChaosReplaceActions item) {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this, item);
    }
    ReplaceNestedImpl() {
      this.builder = new PodHttpChaosReplaceActionsBuilder(this);
    }
    PodHttpChaosReplaceActionsBuilder builder;
    public N and() {
      return (N) PodHttpChaosActionsFluentImpl.this.withReplace(builder.build());
    }
    public N endReplace() {
      return and();
    }
    
  }
  
}
